#!/usr/bin/python3.1
# pythagoras 4.py
# a GUI for working out pythagoras theorem
#
# Version 4: Calculates missing value a, b or c
#

# import some modules tkinter for a canvas
from tkinter import *
import math           #for square root function

# the function called when button or Enter is pressed
def calculate(*ignore):

    rad = radio.get()   #get selected radio button state
    if rad == 3:    #calculating c (hypotenuse)
        calcHypotenuse()
    else:            #calculating a or b
        calcSide(rad)
    
#calculate side
def calcSide(rad):
    a = value_a.get()
    b = value_b.get()
    c = value_c.get()
    errfound = FALSE
    
    #validation of inputs are they integers and not zero?
    if rad == 1:    #calculating a so we have b
        if not b.isdigit() or int(b) <= 0:
            message = "Please enter length of side b above 0"
            errfound = TRUE
            
    else:        #calculating b so we have a
        if not a.isdigit() or int(a) <= 0:
            message = "Please enter length of side a above 0"
            errfound = TRUE

    if errfound == FALSE:   #no error found yet ...
        #we'll always have c ...
        if not c.isdigit() or int(c) <= 0:
            message = "Please enter length of side c above 0"
        else:
            #if here we have two numbers and both above 0
            if rad == 1:    #calculating a so we have b
                sidesquared = int(b) * int(b)
                sidetocalc = "a"
            else:    #calculating b so we have a
                sidesquared = int(a) * int(a)
                sidetocalc = "b"

            csquared = int(c) * int(c)
            othersidesquared = csquared - sidesquared
            otherside = math.sqrt(othersidesquared) 
            message = "Length of " + sidetocalc + " is " + str(otherside)

    display(message)
  

#calculate Hypotenuse function
def calcHypotenuse(*ignore):
    #This function takes values for a and b and calculates
    #the value for the hypotenuse (c)
    #
    #formula is (a*a) + (b*b) = (c*c)
    #then need square root
    
    #store values from inputs
    a = value_a.get()
    b = value_b.get()

    #validation of inputs
    #are they integers and not zero?

    if not a.isdigit() or int(a) <= 0:
        message = "Please enter length of side a above 0"
        
    elif not b.isdigit() or int(b) <= 0:
        message = "Please enter length of side b above 0"

    else:
        #if here we have two numbers and both above 0
        asquared = int(a) * int(a)
        bsquared = int(b) * int(b)
        csquared = asquared + bsquared
        c = math.sqrt(csquared) 
        message = "Length of hypotenuse is " + str(c)
    display(message)

#enable entry a, b or c depending on which radio button pressed
def enableEntry(*ignore):
    rad = radio.get()   #get selected radio button state

    #delete contents of entries
    value_a.configure(state = "normal")
    value_b.configure(state = "normal")
    value_c.configure(state = "normal")
    value_a.delete(0, END)
    value_b.delete(0, END)
    value_c.delete(0, END)

    if rad == 1:    #a selected - enable b and c
        value_a.configure(state = "disabled")
        value_b.configure(state = "normal")
        value_c.configure(state = "normal")
    elif rad == 2:  #b selected - enable a and c
        value_a.configure(state = "normal")
        value_b.configure(state = "disabled")
        value_c.configure(state = "normal")
    else:       #c selected - enable a and b
        value_a.configure(state = "normal")
        value_b.configure(state = "normal")
        value_c.configure(state = "disabled")

    value_a.update()
    value_b.update()
    value_c.update() 

# text display function
def display(message):
    """Simple text display function. Takes a string."""
    txt["state"] = "normal"
    txt.delete(0.0, END)
    txt.insert(0.0, message)
    txt["state"] = "disabled"

# set up the GUI
root = Tk()
root.resizable(0,0) #stop window from being resized
app = Frame(root)   #create the frame
app.grid()          #use a grid to layout the frame

#bind the calculate function to <Return> (Enter key) event
#in other words call calculate when calc button pressed or enter pressed
root.bind('<Return>', calculate)   

root.title("Pythagoras v4")    #GUI title
root.geometry("400x500")    #GUI size

#box for messages and output
txt = Text(app, width = 49, height = 3, wrap = WORD, state = DISABLED)
txt.grid(row = 7, column = 0, columnspan = 3, padx = 1, pady = 1,sticky = W)

# create a Label and import the picture 
picture = Label(app)
picture.grid(row = 0, columnspan = 3, sticky = W)   #sticky = W means left aligned
pythagoras = PhotoImage(file = "pythagoras.gif")
picture["image"] = pythagoras

ask_lbl = Label(app, text = "Which length do you wish to calculate?")
ask_lbl.grid(row = 1, columnspan = 3, sticky = W)

#create entry inputs - set to disabled (status changes depending on radio button)
ask_lbl = Label(app, text = "Please enter length of side a")
ask_lbl.grid(row = 3, column = 0, sticky = W)
value_a = Entry(app, width = 10, state = DISABLED)
value_a.grid(row = 3, column = 1, sticky = W)

ask_lbl = Label(app, text = "Please enter length of side b")
ask_lbl.grid(row = 4, column = 0, sticky = W)
value_b = Entry(app, width = 10, state = DISABLED)
value_b.grid(row = 4, column = 1, sticky = W)

ask_lbl = Label(app, text = "Please enter length of side c")
ask_lbl.grid(row = 5, column = 0, sticky = W)
value_c = Entry(app, width = 10, state = DISABLED)
value_c.grid(row = 5, column = 1, sticky = W)

#set up radio buttons - when selected call enableEntry function to set Entry state
radio = IntVar()
rad = Radiobutton(app, text="a", variable = radio, value = 1, command = enableEntry)
rad.grid(row = 2, column = 0, sticky = E)
rad = Radiobutton(app, text="b", variable = radio, value = 2, command = enableEntry)
rad.grid(row = 2, column = 1)
rad = Radiobutton(app, text="c", variable = radio, value = 3, command = enableEntry)
rad.grid(row = 2, column = 2, sticky = W)

calc = Button(app, text = "Calculate!")
calc["command"] = calculate          #call calculate if button clicked   
calc.grid(row = 6, column = 1, sticky = W)
